/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.base;

public class Plugin extends com.mysql.grt.GrtObject {

    protected Plugin() {
    }

    public Plugin(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new PluginDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new PluginDataGlobal((String) obj);
        }
    }

    public int getSingleArgument() {
        return ((PluginData) data).getSingleArgument();
    }

    public int setSingleArgument(int singleArgument) {
        ((PluginData) data).setSingleArgument(singleArgument);

        return getSingleArgument();
    }

    public String getCaption() {
        return ((PluginData) data).getCaption();
    }

    public String setCaption(String caption) {
        ((PluginData) data).setCaption(caption);

        return getCaption();
    }

    public String getDescription() {
        return ((PluginData) data).getDescription();
    }

    public String setDescription(String description) {
        ((PluginData) data).setDescription(description);

        return getDescription();
    }

    public String getGroupPath() {
        return ((PluginData) data).getGroupPath();
    }

    public String setGroupPath(String groupPath) {
        ((PluginData) data).setGroupPath(groupPath);

        return getGroupPath();
    }

    public String getModuleName() {
        return ((PluginData) data).getModuleName();
    }

    public String setModuleName(String moduleName) {
        ((PluginData) data).setModuleName(moduleName);

        return getModuleName();
    }

    public String getModuleFunctionName() {
        return ((PluginData) data).getModuleFunctionName();
    }

    public String setModuleFunctionName(String moduleFunctionName) {
        ((PluginData) data).setModuleFunctionName(moduleFunctionName);

        return getModuleFunctionName();
    }

    public com.mysql.grt.GrtStringList getCategories() {
        return ((PluginData) data).getCategories();
    }

    public com.mysql.grt.GrtStringList setCategories(com.mysql.grt.GrtStringList categories) {
        ((PluginData) data).setCategories(categories);

        return getCategories();
    }

    public com.mysql.grt.GrtStringList getObjectStructNames() {
        return ((PluginData) data).getObjectStructNames();
    }

    public com.mysql.grt.GrtStringList setObjectStructNames(com.mysql.grt.GrtStringList objectStructNames) {
        ((PluginData) data).setObjectStructNames(objectStructNames);

        return getObjectStructNames();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"singleArgument\">"
                    + Integer.toString(getSingleArgument()) + "</value>\n");

            if (getCaption() != null) {
                xml.append("<value type=\"string\" key=\"caption\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCaption()) + "</value>\n");
            }

            if (getDescription() != null) {
                xml.append("<value type=\"string\" key=\"description\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDescription()) + "</value>\n");
            }

            if (getGroupPath() != null) {
                xml.append("<value type=\"string\" key=\"groupPath\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getGroupPath()) + "</value>\n");
            }

            if (getModuleName() != null) {
                xml.append("<value type=\"string\" key=\"moduleName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getModuleName()) + "</value>\n");
            }

            if (getModuleFunctionName() != null) {
                xml.append("<value type=\"string\" key=\"moduleFunctionName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getModuleFunctionName()) + "</value>\n");
            }

            if (getCategories() != null) {
                getCategories().getGrtXml(xml, " key=\"categories\"");
            }

            if (getObjectStructNames() != null) {
                getObjectStructNames().getGrtXml(xml, " key=\"objectStructNames\"");
            }

        return xml;
    }
}
