/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.maxdb;

public class Table extends com.mysql.grt.db.Table {

    protected Table() {
    }

    public Table(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new TableDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new TableDataGlobal((String) obj);
        }
    }

    public int getNoFixedLengthColumn() {
        return ((TableData) data).getNoFixedLengthColumn();
    }

    public int setNoFixedLengthColumn(int noFixedLengthColumn) {
        ((TableData) data).setNoFixedLengthColumn(noFixedLengthColumn);

        return getNoFixedLengthColumn();
    }

    public String getSample() {
        return ((TableData) data).getSample();
    }

    public String setSample(String sample) {
        ((TableData) data).setSample(sample);

        return getSample();
    }

    public String getCreateDate() {
        return ((TableData) data).getCreateDate();
    }

    public String setCreateDate(String createDate) {
        ((TableData) data).setCreateDate(createDate);

        return getCreateDate();
    }

    public String getCreateTime() {
        return ((TableData) data).getCreateTime();
    }

    public String setCreateTime(String createTime) {
        ((TableData) data).setCreateTime(createTime);

        return getCreateTime();
    }

    public String getUpdStatDate() {
        return ((TableData) data).getUpdStatDate();
    }

    public String setUpdStatDate(String updStatDate) {
        ((TableData) data).setUpdStatDate(updStatDate);

        return getUpdStatDate();
    }

    public String getUpdStatTime() {
        return ((TableData) data).getUpdStatTime();
    }

    public String setUpdStatTime(String updStatTime) {
        ((TableData) data).setUpdStatTime(updStatTime);

        return getUpdStatTime();
    }

    public String getAlterDate() {
        return ((TableData) data).getAlterDate();
    }

    public String setAlterDate(String alterDate) {
        ((TableData) data).setAlterDate(alterDate);

        return getAlterDate();
    }

    public String getAlterTime() {
        return ((TableData) data).getAlterTime();
    }

    public String setAlterTime(String alterTime) {
        ((TableData) data).setAlterTime(alterTime);

        return getAlterTime();
    }

    public String getUnloaded() {
        return ((TableData) data).getUnloaded();
    }

    public String setUnloaded(String unloaded) {
        ((TableData) data).setUnloaded(unloaded);

        return getUnloaded();
    }

    public String getPrivileges() {
        return ((TableData) data).getPrivileges();
    }

    public String setPrivileges(String privileges) {
        ((TableData) data).setPrivileges(privileges);

        return getPrivileges();
    }

    public String getComment() {
        return ((TableData) data).getComment();
    }

    public String setComment(String comment) {
        ((TableData) data).setComment(comment);

        return getComment();
    }

    public String getTableid() {
        return ((TableData) data).getTableid();
    }

    public String setTableid(String tableid) {
        ((TableData) data).setTableid(tableid);

        return getTableid();
    }

    public String getArchive() {
        return ((TableData) data).getArchive();
    }

    public String setArchive(String archive) {
        ((TableData) data).setArchive(archive);

        return getArchive();
    }

    public String getVariableColumns() {
        return ((TableData) data).getVariableColumns();
    }

    public String setVariableColumns(String variableColumns) {
        ((TableData) data).setVariableColumns(variableColumns);

        return getVariableColumns();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"noFixedLengthColumn\">"
                    + Integer.toString(getNoFixedLengthColumn()) + "</value>\n");

            if (getSample() != null) {
                xml.append("<value type=\"string\" key=\"sample\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getSample()) + "</value>\n");
            }

            if (getCreateDate() != null) {
                xml.append("<value type=\"string\" key=\"createDate\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCreateDate()) + "</value>\n");
            }

            if (getCreateTime() != null) {
                xml.append("<value type=\"string\" key=\"createTime\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCreateTime()) + "</value>\n");
            }

            if (getUpdStatDate() != null) {
                xml.append("<value type=\"string\" key=\"updStatDate\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getUpdStatDate()) + "</value>\n");
            }

            if (getUpdStatTime() != null) {
                xml.append("<value type=\"string\" key=\"updStatTime\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getUpdStatTime()) + "</value>\n");
            }

            if (getAlterDate() != null) {
                xml.append("<value type=\"string\" key=\"alterDate\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getAlterDate()) + "</value>\n");
            }

            if (getAlterTime() != null) {
                xml.append("<value type=\"string\" key=\"alterTime\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getAlterTime()) + "</value>\n");
            }

            if (getUnloaded() != null) {
                xml.append("<value type=\"string\" key=\"unloaded\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getUnloaded()) + "</value>\n");
            }

            if (getPrivileges() != null) {
                xml.append("<value type=\"string\" key=\"privileges\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getPrivileges()) + "</value>\n");
            }

            if (getComment() != null) {
                xml.append("<value type=\"string\" key=\"comment\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getComment()) + "</value>\n");
            }

            if (getTableid() != null) {
                xml.append("<value type=\"string\" key=\"tableid\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getTableid()) + "</value>\n");
            }

            if (getArchive() != null) {
                xml.append("<value type=\"string\" key=\"archive\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getArchive()) + "</value>\n");
            }

            if (getVariableColumns() != null) {
                xml.append("<value type=\"string\" key=\"variableColumns\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getVariableColumns()) + "</value>\n");
            }

        return xml;
    }
}
