/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.mgmt;

public class Driver extends com.mysql.grt.GrtObject {

    protected Driver() {
    }

    public Driver(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new DriverDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new DriverDataGlobal((String) obj);
        }
    }

    public int getIsAccessable() {
        return ((DriverData) data).getIsAccessable();
    }

    public int setIsAccessable(int isAccessable) {
        ((DriverData) data).setIsAccessable(isAccessable);

        return getIsAccessable();
    }

    public int getIsInstalled() {
        return ((DriverData) data).getIsInstalled();
    }

    public int setIsInstalled(int isInstalled) {
        ((DriverData) data).setIsInstalled(isInstalled);

        return getIsInstalled();
    }

    public String getCaption() {
        return ((DriverData) data).getCaption();
    }

    public String setCaption(String caption) {
        ((DriverData) data).setCaption(caption);

        return getCaption();
    }

    public String getDescription() {
        return ((DriverData) data).getDescription();
    }

    public String setDescription(String description) {
        ((DriverData) data).setDescription(description);

        return getDescription();
    }

    public String getFilesTarget() {
        return ((DriverData) data).getFilesTarget();
    }

    public String setFilesTarget(String filesTarget) {
        ((DriverData) data).setFilesTarget(filesTarget);

        return getFilesTarget();
    }

    public String getDownloadUrl() {
        return ((DriverData) data).getDownloadUrl();
    }

    public String setDownloadUrl(String downloadUrl) {
        ((DriverData) data).setDownloadUrl(downloadUrl);

        return getDownloadUrl();
    }

    public com.mysql.grt.GrtStringHashMap getDefaultModules() {
        return ((DriverData) data).getDefaultModules();
    }

    public com.mysql.grt.GrtStringHashMap setDefaultModules(com.mysql.grt.GrtStringHashMap defaultModules) {
        ((DriverData) data).setDefaultModules(defaultModules);

        return getDefaultModules();
    }

    public com.mysql.grt.GrtStringList getFiles() {
        return ((DriverData) data).getFiles();
    }

    public com.mysql.grt.GrtStringList setFiles(com.mysql.grt.GrtStringList files) {
        ((DriverData) data).setFiles(files);

        return getFiles();
    }

    public com.mysql.grt.db.mgmt.DriverParameterList getParameters() {
        return ((DriverData) data).getParameters();
    }

    public com.mysql.grt.db.mgmt.DriverParameterList setParameters(com.mysql.grt.db.mgmt.DriverParameterList parameters) {
        ((DriverData) data).setParameters(parameters);

        return getParameters();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"isAccessable\">"
                    + Integer.toString(getIsAccessable()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"isInstalled\">"
                    + Integer.toString(getIsInstalled()) + "</value>\n");

            if (getCaption() != null) {
                xml.append("<value type=\"string\" key=\"caption\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCaption()) + "</value>\n");
            }

            if (getDescription() != null) {
                xml.append("<value type=\"string\" key=\"description\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDescription()) + "</value>\n");
            }

            if (getFilesTarget() != null) {
                xml.append("<value type=\"string\" key=\"filesTarget\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getFilesTarget()) + "</value>\n");
            }

            if (getDownloadUrl() != null) {
                xml.append("<value type=\"string\" key=\"downloadUrl\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDownloadUrl()) + "</value>\n");
            }

            if (getFiles() != null) {
                getFiles().getGrtXml(xml, " key=\"files\"");
            }

            if (getParameters() != null) {
                getParameters().getGrtXml(xml, " key=\"parameters\"");
            }

            if (getDefaultModules() != null) {
                getDefaultModules().getGrtXml(xml, " key=\"defaultModules\"");
            }

        return xml;
    }
}
