/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.migration;

public class Method extends com.mysql.grt.GrtObject {

    protected Method() {
    }

    public Method(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new MethodDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new MethodDataGlobal((String) obj);
        }
    }

    public int getRating() {
        return ((MethodData) data).getRating();
    }

    public int setRating(int rating) {
        ((MethodData) data).setRating(rating);

        return getRating();
    }

    public String getModuleName() {
        return ((MethodData) data).getModuleName();
    }

    public String setModuleName(String moduleName) {
        ((MethodData) data).setModuleName(moduleName);

        return getModuleName();
    }

    public String getCaption() {
        return ((MethodData) data).getCaption();
    }

    public String setCaption(String caption) {
        ((MethodData) data).setCaption(caption);

        return getCaption();
    }

    public String getDesc() {
        return ((MethodData) data).getDesc();
    }

    public String setDesc(String desc) {
        ((MethodData) data).setDesc(desc);

        return getDesc();
    }

    public String getSourceStructName() {
        return ((MethodData) data).getSourceStructName();
    }

    public String setSourceStructName(String sourceStructName) {
        ((MethodData) data).setSourceStructName(sourceStructName);

        return getSourceStructName();
    }

    public String getTargetPackageName() {
        return ((MethodData) data).getTargetPackageName();
    }

    public String setTargetPackageName(String targetPackageName) {
        ((MethodData) data).setTargetPackageName(targetPackageName);

        return getTargetPackageName();
    }

    public com.mysql.grt.GrtStringHashMap getParams() {
        return ((MethodData) data).getParams();
    }

    public com.mysql.grt.GrtStringHashMap setParams(com.mysql.grt.GrtStringHashMap params) {
        ((MethodData) data).setParams(params);

        return getParams();
    }

    public com.mysql.grt.db.migration.ParameterGroupList getParamGroups() {
        return ((MethodData) data).getParamGroups();
    }

    public com.mysql.grt.db.migration.ParameterGroupList setParamGroups(com.mysql.grt.db.migration.ParameterGroupList paramGroups) {
        ((MethodData) data).setParamGroups(paramGroups);

        return getParamGroups();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"rating\">"
                    + Integer.toString(getRating()) + "</value>\n");

            if (getModuleName() != null) {
                xml.append("<value type=\"string\" key=\"moduleName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getModuleName()) + "</value>\n");
            }

            if (getCaption() != null) {
                xml.append("<value type=\"string\" key=\"caption\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCaption()) + "</value>\n");
            }

            if (getDesc() != null) {
                xml.append("<value type=\"string\" key=\"desc\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDesc()) + "</value>\n");
            }

            if (getSourceStructName() != null) {
                xml.append("<value type=\"string\" key=\"sourceStructName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getSourceStructName()) + "</value>\n");
            }

            if (getTargetPackageName() != null) {
                xml.append("<value type=\"string\" key=\"targetPackageName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getTargetPackageName()) + "</value>\n");
            }

            if (getParamGroups() != null) {
                getParamGroups().getGrtXml(xml, " key=\"paramGroups\"");
            }

            if (getParams() != null) {
                getParams().getGrtXml(xml, " key=\"params\"");
            }

        return xml;
    }
}
