/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.oracle;

public class Table extends com.mysql.grt.db.Table {

    protected Table() {
    }

    public Table(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new TableDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new TableDataGlobal((String) obj);
        }
    }

    public int getPctFreeBlockSpace() {
        return ((TableData) data).getPctFreeBlockSpace();
    }

    public int setPctFreeBlockSpace(int pctFreeBlockSpace) {
        ((TableData) data).setPctFreeBlockSpace(pctFreeBlockSpace);

        return getPctFreeBlockSpace();
    }

    public int getPctUsedBlockSpace() {
        return ((TableData) data).getPctUsedBlockSpace();
    }

    public int setPctUsedBlockSpace(int pctUsedBlockSpace) {
        ((TableData) data).setPctUsedBlockSpace(pctUsedBlockSpace);

        return getPctUsedBlockSpace();
    }

    public int getInitialTrans() {
        return ((TableData) data).getInitialTrans();
    }

    public int setInitialTrans(int initialTrans) {
        ((TableData) data).setInitialTrans(initialTrans);

        return getInitialTrans();
    }

    public int getMaxTrans() {
        return ((TableData) data).getMaxTrans();
    }

    public int setMaxTrans(int maxTrans) {
        ((TableData) data).setMaxTrans(maxTrans);

        return getMaxTrans();
    }

    public int getInitialExtent() {
        return ((TableData) data).getInitialExtent();
    }

    public int setInitialExtent(int initialExtent) {
        ((TableData) data).setInitialExtent(initialExtent);

        return getInitialExtent();
    }

    public int getNextExtent() {
        return ((TableData) data).getNextExtent();
    }

    public int setNextExtent(int nextExtent) {
        ((TableData) data).setNextExtent(nextExtent);

        return getNextExtent();
    }

    public int getMinExtents() {
        return ((TableData) data).getMinExtents();
    }

    public int setMinExtents(int minExtents) {
        ((TableData) data).setMinExtents(minExtents);

        return getMinExtents();
    }

    public int getMaxExtents() {
        return ((TableData) data).getMaxExtents();
    }

    public int setMaxExtents(int maxExtents) {
        ((TableData) data).setMaxExtents(maxExtents);

        return getMaxExtents();
    }

    public int getPctIncrease() {
        return ((TableData) data).getPctIncrease();
    }

    public int setPctIncrease(int pctIncrease) {
        ((TableData) data).setPctIncrease(pctIncrease);

        return getPctIncrease();
    }

    public int getNumRows() {
        return ((TableData) data).getNumRows();
    }

    public int setNumRows(int numRows) {
        ((TableData) data).setNumRows(numRows);

        return getNumRows();
    }

    public int getBlocks() {
        return ((TableData) data).getBlocks();
    }

    public int setBlocks(int blocks) {
        ((TableData) data).setBlocks(blocks);

        return getBlocks();
    }

    public int getEmptyBlocks() {
        return ((TableData) data).getEmptyBlocks();
    }

    public int setEmptyBlocks(int emptyBlocks) {
        ((TableData) data).setEmptyBlocks(emptyBlocks);

        return getEmptyBlocks();
    }

    public int getAvgSpace() {
        return ((TableData) data).getAvgSpace();
    }

    public int setAvgSpace(int avgSpace) {
        ((TableData) data).setAvgSpace(avgSpace);

        return getAvgSpace();
    }

    public int getAvgRowLen() {
        return ((TableData) data).getAvgRowLen();
    }

    public int setAvgRowLen(int avgRowLen) {
        ((TableData) data).setAvgRowLen(avgRowLen);

        return getAvgRowLen();
    }

    public int getIsNestedTable() {
        return ((TableData) data).getIsNestedTable();
    }

    public int setIsNestedTable(int isNestedTable) {
        ((TableData) data).setIsNestedTable(isNestedTable);

        return getIsNestedTable();
    }

    public String getTablespaceName() {
        return ((TableData) data).getTablespaceName();
    }

    public String setTablespaceName(String tablespaceName) {
        ((TableData) data).setTablespaceName(tablespaceName);

        return getTablespaceName();
    }

    public String getClusterName() {
        return ((TableData) data).getClusterName();
    }

    public String setClusterName(String clusterName) {
        ((TableData) data).setClusterName(clusterName);

        return getClusterName();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"pctFreeBlockSpace\">"
                    + Integer.toString(getPctFreeBlockSpace()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"pctUsedBlockSpace\">"
                    + Integer.toString(getPctUsedBlockSpace()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"initialTrans\">"
                    + Integer.toString(getInitialTrans()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"maxTrans\">"
                    + Integer.toString(getMaxTrans()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"initialExtent\">"
                    + Integer.toString(getInitialExtent()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"nextExtent\">"
                    + Integer.toString(getNextExtent()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"minExtents\">"
                    + Integer.toString(getMinExtents()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"maxExtents\">"
                    + Integer.toString(getMaxExtents()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"pctIncrease\">"
                    + Integer.toString(getPctIncrease()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"numRows\">"
                    + Integer.toString(getNumRows()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"blocks\">"
                    + Integer.toString(getBlocks()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"emptyBlocks\">"
                    + Integer.toString(getEmptyBlocks()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"avgSpace\">"
                    + Integer.toString(getAvgSpace()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"avgRowLen\">"
                    + Integer.toString(getAvgRowLen()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"isNestedTable\">"
                    + Integer.toString(getIsNestedTable()) + "</value>\n");

            if (getTablespaceName() != null) {
                xml.append("<value type=\"string\" key=\"tablespaceName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getTablespaceName()) + "</value>\n");
            }

            if (getClusterName() != null) {
                xml.append("<value type=\"string\" key=\"clusterName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getClusterName()) + "</value>\n");
            }

        return xml;
    }
}
