/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.workbench;

public class Workbench extends com.mysql.grt.GrtObject {

    protected Workbench() {
    }

    public Workbench(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new WorkbenchDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new WorkbenchDataGlobal((String) obj);
        }
    }

    public int getVersion() {
        return ((WorkbenchData) data).getVersion();
    }

    public int setVersion(int version) {
        ((WorkbenchData) data).setVersion(version);

        return getVersion();
    }

    public com.mysql.grt.db.mgmt.Connection getConnection() {
        return ((WorkbenchData) data).getConnection();
    }

    public com.mysql.grt.db.mgmt.Connection setConnection(com.mysql.grt.db.mgmt.Connection connection) {
        ((WorkbenchData) data).setConnection(connection);

        return getConnection();
    }

    public com.mysql.grt.db.Catalog getCatalog() {
        return ((WorkbenchData) data).getCatalog();
    }

    public com.mysql.grt.db.Catalog setCatalog(com.mysql.grt.db.Catalog catalog) {
        ((WorkbenchData) data).setCatalog(catalog);

        return getCatalog();
    }

    public com.mysql.grt.db.workbench.Model getModel() {
        return ((WorkbenchData) data).getModel();
    }

    public com.mysql.grt.db.workbench.Model setModel(com.mysql.grt.db.workbench.Model model) {
        ((WorkbenchData) data).setModel(model);

        return getModel();
    }

    public com.mysql.grt.GrtHashMap getCustomData() {
        return ((WorkbenchData) data).getCustomData();
    }

    public com.mysql.grt.GrtHashMap setCustomData(com.mysql.grt.GrtHashMap customData) {
        ((WorkbenchData) data).setCustomData(customData);

        return getCustomData();
    }

    public com.mysql.grt.db.mgmt.Rdbms getRdbms() {
        return ((WorkbenchData) data).getRdbms();
    }

    public com.mysql.grt.db.mgmt.Rdbms setRdbms(com.mysql.grt.db.mgmt.Rdbms rdbms) {
        ((WorkbenchData) data).setRdbms(rdbms);

        return getRdbms();
    }

    public String getRdbmsById() {
        return ((WorkbenchData) data).getRdbmsById();
    }

    public void setRdbmsById(String rdbms) {
        ((WorkbenchData) data).setRdbmsById(rdbms);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"version\">"
                    + Integer.toString(getVersion()) + "</value>\n");

            if (getConnection() != null) {
                getConnection().getGrtXml(xml, " key=\"connection\"");
            }

            if (getCatalog() != null) {
                getCatalog().getGrtXml(xml, " key=\"catalog\"");
            }

            if (getModel() != null) {
                getModel().getGrtXml(xml, " key=\"model\"");
            }

            if (getCustomData() != null) {
                getCustomData().getGrtXml(xml, " key=\"customData\"");
            }

            if (getRdbms() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"rdbms\">"
                        + getRdbmsById() + "</value>\n");
            }

        return xml;
    }
}
